# !!! WiP !!! Android idle bypass script by (pussious) cfati

import sys


def simulate(verbose=False):
    print("Platform not supported!")
    sys.exit(-1)


if __name__ == "__main__":
    print("This script is not meant to be run directly.\n")
    sys.exit(-1)



# Idle bypass script by (pussious) cfati

import argparse
import random

from pycfutils.io import read_key
from pycfutils.miscellaneous import timestamp_string

import pyshallow.gen_evt as ge


def parse_args(*argv):
    parser = argparse.ArgumentParser(description="Suppress screen saver / turn off")
    parser.add_argument(
        "--base_interval",
        "-i",
        default=180,
        type=int,
        help="interval (seconds) between 2 consecutive events generation",
    )
    parser.add_argument(
        "--key_interval",
        "-k",
        default=0.5,
        type=float,
        help="time (max seconds) needed by the script"
        " to become responsive to user input (keyboard)",
    )
    parser.add_argument(
        "--max_deviation_percent",
        "-p",
        default=10,
        type=int,
        help="maximum base interval deviation percent."
        " A constant interval might be an indicator for monitoring tools"
        " that something fishy is going on. Adding some randomization,"
        " so each interval is different. Make sure that if an event is required to happen"
        " in a certain amount of time, base interval + maximum deviation fits into that:"
        " `base_interval * (1 + max_deviation_percent) <= max_event_timeout`",
    )
    parser.add_argument("--verbose", "-v", action="store_true", help="verbose mode")

    args, unk = parser.parse_known_args()
    if unk:
        print("Warning: Ignoring unknown arguments: {:}".format(unk))

    if args.max_deviation_percent < 0:
        parser.exit(status=-1, message="Percent must be non negative\n")
    if args.base_interval <= 0 or args.key_interval <= 0:
        parser.exit(status=-1, message="Intervals must be positive\n")

    return args, unk


def generate_interval(base, deviation_percent):
    max_dev = base * deviation_percent / 100
    dev = max_dev * 2 * random.random()
    return max(round(base - max_dev + dev), 1)


def main(*argv):
    args, _ = parse_args()

    verbose_text_pat = (
        "\n{:s}\nAttempting to (fakely) move the mouse in {:d} seconds.\n"
        "  At any point, press any key to interrupt..."
    )

    while True:
        interval = generate_interval(args.base_interval, args.max_deviation_percent)
        if args.verbose:
            print(
                verbose_text_pat.format(
                    timestamp_string(human_readable=False)[2:], interval
                )
            )
        ge.simulate(verbose=args.verbose)
        if read_key(timeout=interval, poll_interval=args.key_interval):
            if args.verbose:
                print("\nKey pressed. Exiting.")
            break



# Nix (X11) idle bypass script by (pussious) cfati

import ctypes as cts
import os
import socket
import sys
from ctypes.util import find_library

import pycfutils.network as pcun

IntPtr = cts.POINTER(cts.c_int)
UIntPtr = cts.POINTER(cts.c_uint)
DisplayPtr = cts.c_void_p
Bool = cts.c_int
XID = cts.c_ulong
Window = XID
WindowPtr = cts.POINTER(Window)

lib_path = find_library("X11")
if not lib_path:
    print("Error loading X lib")
    sys.exit(-1)
X11 = cts.CDLL(lib_path)

XOpenDisplay = X11.XOpenDisplay
XOpenDisplay.argtypes = (cts.c_char_p,)
XOpenDisplay.restype = DisplayPtr

XWarpPointer = X11.XWarpPointer
XWarpPointer.argtypes = (
    DisplayPtr,
    Window,
    Window,
    cts.c_int,
    cts.c_int,
    cts.c_uint,
    cts.c_uint,
    cts.c_int,
    cts.c_int,
)
XWarpPointer.restype = Bool

XDefaultRootWindow = X11.XDefaultRootWindow
XDefaultRootWindow.argtypes = (DisplayPtr,)
XDefaultRootWindow.restype = Window

XQueryPointer = X11.XQueryPointer
XQueryPointer.argtypes = (
    DisplayPtr,
    Window,
    WindowPtr,
    WindowPtr,
    IntPtr,
    IntPtr,
    IntPtr,
    IntPtr,
    UIntPtr,
)
XQueryPointer.restype = Bool

XFlush = X11.XFlush
XFlush.argtypes = (DisplayPtr,)
XFlush.restype = cts.c_int

XCloseDisplay = X11.XCloseDisplay
XCloseDisplay.argtypes = (DisplayPtr,)
XCloseDisplay.restype = None

_x_quick_check = True


def _is_x_server_listening():
    fails = (ConnectionRefusedError, socket.timeout)
    hds = os.environ.get("DISPLAY", "").split(":")
    host = "localhost"
    port = 6000
    if hds[0]:
        host = hds[0]
    if len(hds) == 2:
        d = hds[1].split(".")
        if d[0].isnumeric():
            port += int(d[0])
    try:
        pcun.connect_to_server(host, port, pcun.SOCKET_FAMILY_IPV4, attempt_timeout=0.5)
    except Exception as e:
        if isinstance(getattr(e, "__cause__"), fails):
            return False
    return True


def _open_display(name=None, quit_on_error=False, verbose=False):
    global _x_quick_check
    if _x_quick_check:
        if not _is_x_server_listening():
            if (
                input(
                    "A quick test shows that no XServer is listening."
                    " Press Y/y to continue anyway (in a possibly unresponsive manner): "
                ).lower()
                != "y"
            ):
                print("Aborted by user.")
                sys.exit(-1)
        _x_quick_check = False
    disp_ptr = XOpenDisplay(name)
    if not disp_ptr:
        if verbose:
            print("Error contacting XServer.")
        if quit_on_error:
            sys.exit(-1)
    return disp_ptr


def simulate(verbose=False):
    display_ptr = _open_display(verbose=verbose)
    if not display_ptr:
        return
    root_window = XDefaultRootWindow(display_ptr)
    root_wnd, child_wnd = Window(), Window()
    root_x, root_y = cts.c_int(0), cts.c_int(0)
    child_x, child_y = cts.c_int(0), cts.c_int(0)
    mask = cts.c_uint(0)

    res = XQueryPointer(
        display_ptr,
        root_window,
        cts.byref(root_wnd),
        cts.byref(child_wnd),
        cts.byref(root_x),
        cts.byref(root_y),
        cts.byref(child_x),
        cts.byref(child_y),
        cts.byref(mask),
    )
    if verbose:
        if res:
            print("Mouse at ({:d}, {:d}).".format(root_x.value, root_y.value))
        else:
            print("Error getting cursor position.")

    res = XWarpPointer(display_ptr, 0, 0, 0, 0, 0, 0, 0, 0)
    if verbose:
        if res:
            print("Sent fake mouse move event.")
        else:
            print("Error setting cursor position.")

    XFlush(display_ptr)
    XCloseDisplay(display_ptr)


if __name__ == "__main__":
    print("This script is not meant to be run directly.\n")
    sys.exit(-1)



# Idle bypass script by (pussious) cfati

import sys

plat = sys.platform.lower()
if plat[:3] == "win":
    from ._win import simulate
else:
    if plat == "darwin":
        from ._osx import simulate
    elif hasattr(sys, "getandroidapilevel"):
        from ._android import simulate
    # elif :  # More conditions could come here
    else:
        from ._x11 import simulate


__all__ = ("simulate",)


if __name__ == "__main__":
    print("This module is not meant to be run directly.\n")
    sys.exit(-1)



# OSX idle bypass script by (pussious) cfati

import ctypes as cts
import sys
from ctypes.util import find_library

CGFloat = cts.c_double if sys.maxsize > 0x100000000 else cts.c_float
UInt32 = cts.c_uint32
CGEventRef = cts.c_void_p
CGEventSourceRef = cts.c_void_p
CGEventTapLocation = UInt32

cgSessionEventTap = 1
mouseMoved = 5


class CGPoint(cts.Structure):
    _fields_ = (
        ("x", CGFloat),
        ("y", CGFloat),
    )


lib_path = find_library("CoreGraphics")
if not lib_path:
    print("Error loading Graphics lib")
    sys.exit(-1)
CoreGraphics = cts.CDLL(lib_path)

CGEventCreate = CoreGraphics.CGEventCreate
CGEventCreate.argtypes = (CGEventSourceRef,)
CGEventCreate.restype = CGEventRef

CGEventGetLocation = CoreGraphics.CGEventGetLocation
CGEventGetLocation.argtypes = (CGEventRef,)
CGEventGetLocation.restype = CGPoint

CFRelease = CoreGraphics.CFRelease
CFRelease.argtypes = (CGEventRef,)
CFRelease.restype = None

CGEventPost = CoreGraphics.CGEventPost
CGEventPost.argtypes = (CGEventTapLocation, CGEventSourceRef)
CGEventPost.restype = None

__warn = True


def simulate(verbose=False):
    global __warn
    if __warn:
        print(
            "-----"
            " If it doesn't work, the application running this script"
            " (e.g. Terminal) must be granted the 'Accessibility' permission"
            " -----"
        )
        __warn = False
    # evt = CGEventCreateMouseEvent(None, mouseMoved, CGPoint(-1, -1), -1)
    evt = CGEventCreate(None)
    if not evt:
        if verbose:
            print("Error setting cursor position.")
        return
    pt = CGEventGetLocation(evt)
    # ret = CGDisplayMoveCursorToPoint(CGMainDisplayID(), pt) == success
    # ret = CGWarpMouseCursorPosition(pt) == success
    if verbose:
        print("Mouse at ({:d}, {:d}).".format(round(pt.x), round(pt.y)))
    CGEventPost(cgSessionEventTap, evt)
    if verbose:
        print("Sent fake mouse move event.")
    CFRelease(evt)


if __name__ == "__main__":
    print("This script is not meant to be run directly.\n")
    sys.exit(-1)



# Win idle bypass script by (pussious) cfati

import ctypes as cts
import sys
from ctypes import wintypes as wts

MOUSEEVENTF_MOVE = 0x0001
INPUT_MOUSE = 0x0000


class MOUSEINPUT(cts.Structure):
    _fields_ = (
        ("dx", wts.LONG),
        ("dy", wts.LONG),
        ("mouseData", wts.DWORD),
        ("dwFlags", wts.DWORD),
        ("time", wts.DWORD),
        ("dwExtraInfo", cts.POINTER(wts.ULONG)),
    )


class _INPUT(cts.Union):
    _fields_ = (
        ("mi", MOUSEINPUT),
        ("ki", cts.c_ubyte),  # Dummy field - don't give a phuck
        ("hi", cts.c_ubyte),  # Dummy field - don't give a phuck
    )


class INPUT(cts.Structure):
    _anonymous_ = "u"
    _fields_ = (
        ("type", wts.DWORD),
        ("u", _INPUT),
    )


kernel32 = cts.WinDLL("kernel32.dll")

GetLastError = kernel32.GetLastError
GetLastError.argtypes = ()
GetLastError.restype = wts.DWORD

user32 = cts.WinDLL("user32.dll")

GetCursorPos = user32.GetCursorPos
GetCursorPos.argtypes = (cts.POINTER(wts.POINT),)
GetCursorPos.restype = wts.BOOL

SendInput = user32.SendInput
SendInput.argtypes = (wts.UINT, cts.POINTER(INPUT), cts.c_int)
SendInput.restype = wts.UINT


def simulate(verbose=False):
    point = wts.POINT()
    res = GetCursorPos(cts.byref(point))
    if verbose:
        if res:
            print("Mouse at ({:d}, {:d}).".format(point.x, point.y))
        else:
            print("Error ({:d}) getting cursor position.".format(GetLastError()))
    _input = INPUT()
    _input.type = INPUT_MOUSE
    _input.mi.dx = 0
    _input.mi.dy = 0
    _input.mi.dwFlags = MOUSEEVENTF_MOVE
    event_count = 1
    res = SendInput(event_count, cts.pointer(_input), cts.sizeof(INPUT))
    if verbose:
        if res:
            print("Sent fake mouse move event.")
        else:
            print("Error ({:d}) setting cursor position.".format(GetLastError()))


if __name__ == "__main__":
    print("This script is not meant to be run directly.\n")
    sys.exit(-1)



#!/usr/bin/env python

# Idle bypass script by (pussious) cfati

import sys

from pyshallow import main

print(
    "Python {:s} {:03d}bit on {:s}\n".format(
        " ".join(item.strip() for item in sys.version.split("\n")),
        64 if sys.maxsize > 0x100000000 else 32,
        sys.platform,
    )
)
rc = main(*sys.argv[1:])
print("\nDone.\n")
sys.exit(rc)
